==> openobd_utils-1.11.11.tar.gz: openobd_utils-1.11.11/src/openobd_utils/__init__.py <==
# Copyright (c) 2024 Jifeline Networks B.V.
#
# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"), to deal
# in the Software without restriction, including without limitation the rights
# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
# copies of the Software, and to permit persons to whom the Software is
# furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included in all
# copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
# SOFTWARE.

"""openOBD Python Utilities implementation"""

try:
    # pylint: disable=ungrouped-imports
    from openobd_utils._metadata import __version__
except ImportError:
    __version__ = "dev0"

''' Definitions that are available when using python openobd '''
from .isotp_socket import IsotpSocket as IsotpSocket
from .raw_socket import RawSocket as RawSocket
from .response_exceptions import *

from .ui_handler import UiHandler as UiHandler

from .stream_handler import StreamHandler, OpenOBDStreamException, OpenOBDStreamStoppedException, OpenOBDStreamTimeoutException

from .connection_monitor import ConnectionMonitor

from .session_token_handler import SessionTokenHandler

==> openobd_utils-1.18.20.tar.gz: openobd_utils-1.18.20/src/openobd_utils/__init__.py <==
# Copyright (c) 2024 Jifeline Networks B.V.
#
# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"), to deal
# in the Software without restriction, including without limitation the rights
# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
# copies of the Software, and to permit persons to whom the Software is
# furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included in all
# copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
# SOFTWARE.

"""openOBD Python Utilities implementation"""

try:
    # pylint: disable=ungrouped-imports
    from openobd_utils._metadata import __version__
except ImportError:
    __version__ = "dev0"

''' Definitions that are available when using python openobd '''
from .isotp_socket import IsotpSocket
from .raw_socket import RawSocket
from .kline_socket import KlineSocket
from .terminal15_socket import Terminal15Socket
from .response_exceptions import *

from .ui_handler import UiHandler

from .stream_handler import StreamHandler, OpenOBDStreamException, OpenOBDStreamStoppedException, OpenOBDStreamTimeoutException

from .connection_monitor import ConnectionMonitor

from .session_token_handler import SessionTokenHandler
